@@ -1,8 +1,7 @@
 # SPDX-License-Identifier: AGPL-3.0-or-later
 """Set time zone with timedatectl."""
 
-import subprocess
-
+from plinth import action_utils
 from plinth.actions import privileged
 
 
@@ -10,4 +9,4 @@ from plinth.actions import privileged
 def set_timezone(timezone: str):
     """Set time zone with timedatectl."""
     command = ['timedatectl', 'set-timezone', timezone]
-    subprocess.run(command, stdout=subprocess.DEVNULL, check=True)
+    action_utils.run(command, check=True)
